#!/bin/bash

set -ex

# Junit test vars
CONTAINER_NAME="test-integration-schedule-${CI_COMMIT_SHA}-${CI_JOB_ID}"
TEST_REPORTS_DIR=${TEST_REPORTS_DIR:-"test/test-reports"}
TEST_REPORT_NAME="${CI_COMMIT_SHA}_${CI_JOB_ID}_report.xml"
TEST_REPORT_FULL_PATH="${CI_PROJECT_DIR}/${TEST_REPORTS_DIR}"

# Copy test results from the container if tests pass or fail
function copy_test_results {
    # Create a folder for test reports
    if [[ ! -d "${TEST_REPORT_FULL_PATH}" ]]; then
        mkdir -p "${TEST_REPORT_FULL_PATH}"
    fi

    printf "Copying test report %s to %s \r\n" "${TEST_REPORT_NAME}" "${TEST_REPORT_FULL_PATH}/${TEST_REPORT_NAME}"
    docker cp "${CONTAINER_NAME}:/${TEST_REPORTS_DIR}/${TEST_REPORT_NAME}" "${TEST_REPORT_FULL_PATH}/${TEST_REPORT_NAME}"
    docker rm "${CONTAINER_NAME}"
}

function on_exit {
    copy_test_results
}

# Make sure the copy test report function runs before exit in case of test failures
trap on_exit EXIT

# Build the test container
docker build -t cbc-content-pytest test/pytest_integration/ -f ./docker/tests/Dockerfile.integration

# Run the rest of the tests with passed in markers and excluding integration only tests
if [[ -z "${TEST_MARKERS}" ]] || [[ "${TEST_MARKERS}" == "$TEST_MARKERS" ]]; then
  TEST_MARKERS="not (integration_only or env_smoke)"
else
  TEST_MARKERS="${TEST_MARKERS} and not (integration_only or env_smoke)"
fi

# Run all tests except those not marked for integration only
docker run --name "${CONTAINER_NAME}" \
  -e TEST_ENV="$TEST_ENV" \
  -e CSR_USERNAME="$CSR_USERNAME" \
  -e CSR_PASSWORD="$CSR_PASSWORD" \
  -e TEST_ENV_AWS_ACCESS_KEY_ID="$TEST_ENV_AWS_ACCESS_KEY_ID" \
  -e TEST_ENV_AWS_SECRET_ACCESS_KEY_ID="$TEST_ENV_AWS_SECRET_ACCESS_KEY_ID" \
  cbc-content-pytest pytest --pyargs cbc_content_pacing --tb=short --durations=10 \
  --junitxml="/${TEST_REPORTS_DIR}/${TEST_REPORT_NAME}" -n auto -m "${TEST_MARKERS}"
